==> samsungpay-0.0.1.tar.gz: android/src/main/java/com/example/samsungpay/SamsungpayPlugin.java <==
package com.example.samsungpay;

import android.os.Bundle;
import android.text.TextUtils;
import android.util.Log;
import android.widget.Toast;

import androidx.annotation.NonNull;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

import com.samsung.android.sdk.samsungpay.v2.PartnerInfo;
import com.samsung.android.sdk.samsungpay.v2.SamsungPay;
import com.samsung.android.sdk.samsungpay.v2.SpaySdk;
import com.samsung.android.sdk.samsungpay.v2.StatusListener;
import com.samsung.android.sdk.samsungpay.v2.payment.CardInfo;
import com.samsung.android.sdk.samsungpay.v2.payment.CustomSheetPaymentInfo;

import com.samsung.android.sdk.samsungpay.v2.payment.PaymentManager;
import com.samsung.android.sdk.samsungpay.v2.payment.sheet.CustomSheet;


import java.util.ArrayList;
import java.util.List;


/** SamsungpayPlugin */
public class SamsungpayPlugin implements FlutterPlugin, MethodCallHandler {
  private String SPAY_SERVICE_ID;
  public final String TAG="SamsungpayPlugin";
  AmountDetailControls mAmountDetailControls;
  SampleAppPartnerInfoHolder mSampleAppPartnerInfoHolder;
  PaymentManager mPaymentManager;


  private MethodChannel channel;
  private FlutterPluginBinding binding;

  private double discountedProductAmount;
  private double taxAmount;
  private double shippingAmount;
  private double addedShippingAmount;
  private double addedBillingAmount;
  private String currency;
  private String merchantID;
  private String merchantName;
  private String orderNumber;


  private Result result;


  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "samsungpay");
    binding = flutterPluginBinding;
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);

    } else if (call.method.equals("avaialble")) {
      SPAY_SERVICE_ID=call.argument("spayServiceID");
      samsungpay(result);
    }

    else if (call.method.equals("payNow")) {
      discountedProductAmount=call.argument("ProductAmount");
       taxAmount=call.argument("TaxAmount");
       shippingAmount=call.argument("ShippingAmount");
       addedShippingAmount=call.argument("AddedShippingAmount");
       addedBillingAmount=call.argument("AddedBillingAmount");
      currency=call.argument("currency");
      merchantID=call.argument("merchantID");
      merchantName=call.argument("merchantName");
      orderNumber=call.argument("orderNumber");
      doSamsungPayment(result);
    }

    else {
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  private void doSamsungPayment(@NonNull Result result){
    this.result=result;
    startInAppPayWithCustomSheet();
//    result.success("payment successful");
  }

  protected void startInAppPayWithCustomSheet() {
    Log.d(TAG, "startInAppPayWithCustomSheet");
    Bundle bundle = new Bundle();
    bundle.putString(SamsungPay.PARTNER_SERVICE_TYPE, SamsungPay.ServiceType.INAPP_PAYMENT.toString());
    PartnerInfo partnerInfo = new PartnerInfo(SPAY_SERVICE_ID, bundle);
    partnerInfo.getData().putBoolean(PaymentManager.EXTRA_KEY_TEST_MODE, true);
    // PaymentManager.startInAppPayWithCustomSheet method to show custom payment sheet.
      mSampleAppPartnerInfoHolder = new SampleAppPartnerInfoHolder(binding.getApplicationContext());;

     mPaymentManager = new PaymentManager(binding.getApplicationContext(), partnerInfo );


      runWithTryCatch(() -> mPaymentManager.startInAppPayWithCustomSheet(makeTransactionDetailsWithSheet(),
              transactionListener));


  }

  private void runWithTryCatch(Runnable runnable) {
    try {
      runnable.run();
    } catch (NullPointerException e) {

      displayToastMessageIfRequired(TAG + "NullPointerException, All mandatory fields cannot be null.");
      e.printStackTrace();
    } catch (IllegalStateException e) {

      displayToastMessageIfRequired(TAG + "IllegalStateException");
      e.printStackTrace();
    } catch (NumberFormatException e) {

      displayToastMessageIfRequired(TAG + "NumberFormatException, Amount values is not valid");
      e.printStackTrace();
    } catch (IllegalArgumentException e) {

      displayToastMessageIfRequired(TAG + "IllegalArgumentException, PaymentInfo values are not valid or all " +
              "mandatory " + "fields are not set.");
      e.printStackTrace();
    }
  }

  private void displayToastMessageIfRequired(String msg) {
    Toast.makeText(binding.getApplicationContext(), msg, Toast.LENGTH_LONG).show();
  }



  private CustomSheetPaymentInfo makeTransactionDetailsWithSheet() {
    // Get BrandList (supported card brands)
    /*
    AMERICANEXPRESS,
        MASTERCARD,
        VISA,
        DISCOVER,
        CHINAUNIONPAY,
        UNKNOWN_CARD,
        OCTOPUS,
        ECI,
        PAGOBANCOMAT;
     */
     CardBrandControls mCardBrandControls = new CardBrandControls();
    ArrayList<PaymentManager.Brand> brandList = mCardBrandControls.getBrandList();
    brandList.add(PaymentManager.Brand.VISA);
    brandList.add(PaymentManager.Brand.MASTERCARD);
//    brandList.add(PaymentManager.Brand.AMERICANEXPRESS);
    CustomSheetPaymentInfo customSheetPaymentInfo;

    CustomSheetPaymentInfo.Builder customSheetPaymentInfoBuilder = new CustomSheetPaymentInfo.Builder();

    Bundle extraPaymentInfo = new Bundle();
    String selectCryptogramType = mCardBrandControls.getSelectedCryptogramType(); //encryption method
    if (!TextUtils.equals(selectCryptogramType, "NONE")) {
      extraPaymentInfo.putString(SpaySdk.EXTRA_CRYPTOGRAM_TYPE, selectCryptogramType);
    }
//    if (mCardBrandControls.isComboCardRequested()) {
//      extraPaymentInfo.putBoolean(SpaySdk.EXTRA_ACCEPT_COMBO_CARD, true);
//    }
//    if (mCardBrandControls.isCpfCardRequested()) {
//      extraPaymentInfo.putBoolean(SpaySdk.EXTRA_REQUIRE_CPF, true);
//    }

      mAmountDetailControls = new AmountDetailControls(binding.getApplicationContext(), discountedProductAmount,
     taxAmount,
     shippingAmount,
     addedShippingAmount,
     addedBillingAmount,
              currency);
    AddressRequestListener addressRequestListener = (CustomSheetPaymentInfo.AddressInPaymentSheet type) -> {
//      if (type == CustomSheetPaymentInfo.AddressInPaymentSheet.DO_NOT_SHOW || type == CustomSheetPaymentInfo.AddressInPaymentSheet.NEED_BILLING_SPAY) {
//        mAmountDetailControls.updateAndCheckAmountValidation();
//      }

//      mShippingAddressControls.setNeedAllShippingMethodItems(
//              type == CustomSheetPaymentInfo.AddressInPaymentSheet.NEED_SHIPPING_SPAY || CustomSheetPaymentInfo.AddressInPaymentSheet.NEED_BILLING_AND_SHIPPING == type);
//
//      mBillingAddressControls.updateBillingLayoutVisibility(type);
//      mShippingAddressControls.updateShippingAddressLayout(type);
    };


     RequestAddressOptions mRequestAddressOptions=new RequestAddressOptions(addressRequestListener);
    customSheetPaymentInfoBuilder.setAddressInPaymentSheet(mRequestAddressOptions.getRequestAddressType());
    CustomSheet customSheet = new CustomSheet();
    customSheet.addControl(mAmountDetailControls.makeAmountControl());
    customSheetPaymentInfo = customSheetPaymentInfoBuilder
            .setMerchantId(merchantID)
            .setMerchantName(merchantName)
            .setOrderNumber(orderNumber)
            .setAddressInPaymentSheet(mRequestAddressOptions.getRequestAddressType())
            .setAllowedCardBrands(brandList)
            .setCardHolderNameEnabled(mCardBrandControls.isCardHolderNameRequested())
            .setCustomSheet(customSheet)
            .setExtraPaymentInfo(extraPaymentInfo)
            .build();

    return customSheetPaymentInfo;
  }







  private final PaymentManager.CustomSheetTransactionInfoListener transactionListener
          = new PaymentManager.CustomSheetTransactionInfoListener() {


    @Override
    public void onCardInfoUpdated(CardInfo selectedCardInfo, CustomSheet customSheet) {


      Log.d(TAG, "onCardInfoUpdated " + selectedCardInfo);
      displayToastMessageIfRequired("onCardInfoUpdated");

      mAmountDetailControls.updateAmountControl(customSheet);
      try { mPaymentManager.updateSheet(customSheet);
      } catch (IllegalStateException | NullPointerException e) { e.printStackTrace();
      }

    }


    @Override
    public void onSuccess(CustomSheetPaymentInfo response, String paymentCredential,
                          Bundle extraPaymentData) {
      /*
       * Called when Samsung Pay able to create in-app cryptogram successfully.
       * Partner app will send this cryptogram to Partner server/Payment Gateway and complete in-app payment.
       */

//      Log.d(TAG, "Transaction : paymentCredential " + paymentCredential);
      SamsungpayPlugin.this.result.success(paymentCredential);
//      mPaymentResultDialog.onSuccessDialog(response, paymentCredential, extraPaymentData);
      displayToastMessageIfRequired("Transaction : onSuccess");
    }

    // This callback is received when the online payment transaction has failed.
    @Override
    public void onFailure(int errorCode, Bundle errorData) {
      try {
        String errorName = ErrorCode.getInstance().getErrorCodeName(errorCode);
        int extraReason = 0;
        String extraReasonMsg = null;
        if (errorData != null) {
          extraReason = errorData.getInt(SamsungPay.EXTRA_ERROR_REASON);
          extraReasonMsg = errorData.getString(SamsungPay.EXTRA_ERROR_REASON_MESSAGE);
        }
        Log.d(TAG, "Transaction : onFailure " + errorCode + " / " + errorName + " / " + extraReason);
        displayToastMessageIfRequired("Transaction : onFailure - " + errorCode + " / " + errorName
                + " / " + extraReasonMsg);
      } catch (NullPointerException e) {
        e.printStackTrace();
      }
    }
  };

  private void samsungpay(@NonNull Result result) {
    Bundle bundle = new Bundle();
    bundle.putString(SamsungPay.PARTNER_SERVICE_TYPE, SamsungPay.ServiceType.INAPP_PAYMENT.toString());
    PartnerInfo partnerInfo = new PartnerInfo(SPAY_SERVICE_ID, bundle);
    partnerInfo.getData().putBoolean(PaymentManager.EXTRA_KEY_TEST_MODE, true);
    final SamsungPay samsungPay = new SamsungPay(binding.getApplicationContext(), partnerInfo);

    samsungPay.getSamsungPayStatus(new StatusListener() {
      @Override
      public void onSuccess(int status, Bundle bundle) {
        switch (status) {
        case SamsungPay.SPAY_NOT_SUPPORTED:
          result.error("SPAY_NOT_SUPPORTED", "SPAY_NOT_SUPPORTED", null);
          break;
        case SamsungPay.SPAY_NOT_READY: // Activate Samsung Pay or update Samsung Pay, if needed
          int extra_reason = bundle.getInt(SamsungPay.EXTRA_ERROR_REASON);
          switch (extra_reason) {
          case SamsungPay.ERROR_SPAY_APP_NEED_TO_UPDATE:
            result.error("ERROR_SPAY_APP_NEED_TO_UPDATE", "ERROR_SPAY_APP_NEED_TO_UPDATE", null);
            break;
          case SamsungPay.ERROR_SPAY_SETUP_NOT_COMPLETED:
            samsungPay.activateSamsungPay();
            break;
          default:
            result.error("NOT_READY", "extra reason: " + extra_reason, null);
          }
          break;
        case SamsungPay.SPAY_READY:
          result.success("SPAY_READY");
          PartnerInfo partnerInfo = new PartnerInfo(SPAY_SERVICE_ID, bundle);

          PaymentManager mPaymentManager = new PaymentManager(binding.getApplicationContext(), partnerInfo);

          break;
        default:// Not expected result

          result.error("UNKNOWN", "UNKNOWN", null);
          break;
        }
      }

      @Override
      public void onFail(int errorCode, Bundle bundle) {

        Log.d("SAM", "Failed to initialize Samsung Pay service." + errorCode);
      }
    });
  }
}

==> samsungpay-0.0.4.tar.gz: android/src/main/java/com/example/samsungpay/SamsungpayPlugin.java <==
package com.example.samsungpay;

import android.os.Bundle;
import android.text.TextUtils;
import android.util.Log;
import android.widget.Toast;

import androidx.annotation.NonNull;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

import com.samsung.android.sdk.samsungpay.v2.PartnerInfo;
import com.samsung.android.sdk.samsungpay.v2.SamsungPay;
import com.samsung.android.sdk.samsungpay.v2.SpaySdk;
import com.samsung.android.sdk.samsungpay.v2.StatusListener;
import com.samsung.android.sdk.samsungpay.v2.payment.CardInfo;
import com.samsung.android.sdk.samsungpay.v2.payment.CustomSheetPaymentInfo;

import com.samsung.android.sdk.samsungpay.v2.payment.PaymentInfo;
import com.samsung.android.sdk.samsungpay.v2.payment.PaymentManager;
import com.samsung.android.sdk.samsungpay.v2.payment.sheet.CustomSheet;


import java.util.ArrayList;
import java.util.List;


/** SamsungpayPlugin */
public class SamsungpayPlugin implements FlutterPlugin, MethodCallHandler {
  private String SPAY_SERVICE_ID;
  public final String TAG="SamsungpayPlugin";
  AmountDetailControls mAmountDetailControls;

  PaymentManager mPaymentManager;


  private MethodChannel channel;
  private FlutterPluginBinding binding;

  private double discountedProductAmount;
  private double taxAmount;
  private double shippingAmount;
  private double addedShippingAmount;
  private double addedBillingAmount;
  private String currency;
  private String merchantID;
  private String merchantName;
  private String orderNumber;
  private boolean testmode;


  private Result result;


  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "samsungpay");
    binding = flutterPluginBinding;
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);

    } else if (call.method.equals("avaialble")) {
      SPAY_SERVICE_ID=call.argument("spayServiceID");
      samsungpay(result);
    }
    else if (call.method.equals("payNow")) {
      discountedProductAmount=call.argument("ProductAmount");
      taxAmount=call.argument("TaxAmount");
      shippingAmount=call.argument("ShippingAmount");
      addedShippingAmount=call.argument("AddedShippingAmount");
      addedBillingAmount=call.argument("AddedBillingAmount");
      currency=call.argument("currency");
      merchantID=call.argument("merchantID");
      merchantName=call.argument("merchantName");
      orderNumber=call.argument("orderNumber");
      testmode=call.argument("testMode") ;
      doSamsungPayment(result);
    }else if (call.method.equals("doActivateSamsungPay")) {
      doActivateSamsungPay();
    }
    else {
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  private void doSamsungPayment(@NonNull Result result){
    this.result=result;
    startInAppPayWithCustomSheet();
  }

  protected void startInAppPayWithCustomSheet() {

     mPaymentManager = new PaymentManager(binding.getApplicationContext(), getPartnerInfo() );
      runWithTryCatch(() -> mPaymentManager.startInAppPayWithCustomSheet(makeTransactionDetailsWithSheet(),
              transactionListener));
  }

  private void runWithTryCatch(Runnable runnable) {
    try {
      runnable.run();
    } catch (NullPointerException e) {

      displayToastMessageIfRequired(TAG + "NullPointerException, All mandatory fields cannot be null.");
      e.printStackTrace();
    } catch (IllegalStateException e) {

      displayToastMessageIfRequired(TAG + "IllegalStateException");
      e.printStackTrace();
    } catch (NumberFormatException e) {

      displayToastMessageIfRequired(TAG + "NumberFormatException, Amount values is not valid");
      e.printStackTrace();
    } catch (IllegalArgumentException e) {

      displayToastMessageIfRequired(TAG + "IllegalArgumentException, PaymentInfo values are not valid or all " +
              "mandatory " + "fields are not set.");
      e.printStackTrace();
    }
  }

  private void displayToastMessageIfRequired(String msg) {
    Toast.makeText(binding.getApplicationContext(), msg, Toast.LENGTH_LONG).show();
  }



  private CustomSheetPaymentInfo makeTransactionDetailsWithSheet() {
    // Get BrandList (supported card brands)
    /*
    AMERICANEXPRESS,
        MASTERCARD,
        VISA,
        DISCOVER,
        CHINAUNIONPAY,
        UNKNOWN_CARD,
        OCTOPUS,
        ECI,
        PAGOBANCOMAT;
     */
     CardBrandControls mCardBrandControls = new CardBrandControls();
    ArrayList<PaymentManager.Brand> brandList = mCardBrandControls.getBrandList();
    brandList.add(PaymentManager.Brand.VISA);
    brandList.add(PaymentManager.Brand.MASTERCARD);
    CustomSheetPaymentInfo customSheetPaymentInfo;

    CustomSheetPaymentInfo.Builder customSheetPaymentInfoBuilder = new CustomSheetPaymentInfo.Builder();

    Bundle extraPaymentInfo = new Bundle();
    String selectCryptogramType = mCardBrandControls.getSelectedCryptogramType(); //encryption method
    if (!TextUtils.equals(selectCryptogramType, "NONE")) {
      extraPaymentInfo.putString(SpaySdk.EXTRA_CRYPTOGRAM_TYPE, selectCryptogramType);
    }
//    if (mCardBrandControls.isComboCardRequested()) {
//      extraPaymentInfo.putBoolean(SpaySdk.EXTRA_ACCEPT_COMBO_CARD, true);
//    }
//    if (mCardBrandControls.isCpfCardRequested()) {
//      extraPaymentInfo.putBoolean(SpaySdk.EXTRA_REQUIRE_CPF, true);
//    }

      mAmountDetailControls = new AmountDetailControls(binding.getApplicationContext(), discountedProductAmount,
     taxAmount,
     shippingAmount,
     addedShippingAmount,
     addedBillingAmount,
              currency);
    AddressRequestListener addressRequestListener = (CustomSheetPaymentInfo.AddressInPaymentSheet type) -> {
//      if (type == CustomSheetPaymentInfo.AddressInPaymentSheet.DO_NOT_SHOW || type == CustomSheetPaymentInfo.AddressInPaymentSheet.NEED_BILLING_SPAY) {
//        mAmountDetailControls.updateAndCheckAmountValidation();
//      }

//      mShippingAddressControls.setNeedAllShippingMethodItems(
//              type == CustomSheetPaymentInfo.AddressInPaymentSheet.NEED_SHIPPING_SPAY || CustomSheetPaymentInfo.AddressInPaymentSheet.NEED_BILLING_AND_SHIPPING == type);
//
//      mBillingAddressControls.updateBillingLayoutVisibility(type);
//      mShippingAddressControls.updateShippingAddressLayout(type);
    };


     RequestAddressOptions mRequestAddressOptions=new RequestAddressOptions(addressRequestListener);
    customSheetPaymentInfoBuilder.setAddressInPaymentSheet(mRequestAddressOptions.getRequestAddressType());
    CustomSheet customSheet = new CustomSheet();
    customSheet.addControl(mAmountDetailControls.makeAmountControl());
    customSheetPaymentInfo = customSheetPaymentInfoBuilder
            .setMerchantId(merchantID)
            .setMerchantName(merchantName)
            .setOrderNumber(orderNumber)
            .setAddressInPaymentSheet(mRequestAddressOptions.getRequestAddressType())
            .setAllowedCardBrands(brandList)
            .setCardHolderNameEnabled(mCardBrandControls.isCardHolderNameRequested())
            .setCustomSheet(customSheet)
            .setExtraPaymentInfo(extraPaymentInfo)
            .build();

    return customSheetPaymentInfo;
  }







  private final PaymentManager.CustomSheetTransactionInfoListener transactionListener
          = new PaymentManager.CustomSheetTransactionInfoListener() {


    @Override
    public void onCardInfoUpdated(CardInfo selectedCardInfo, CustomSheet customSheet) {


      Log.d(TAG, "onCardInfoUpdated " + selectedCardInfo);
      displayToastMessageIfRequired("onCardInfoUpdated");

      mAmountDetailControls.updateAmountControl(customSheet);
      try { mPaymentManager.updateSheet(customSheet);
      } catch (IllegalStateException | NullPointerException e) { e.printStackTrace();
      }

    }


    @Override
    public void onSuccess(CustomSheetPaymentInfo response, String paymentCredential,
                          Bundle extraPaymentData) {
      /*
       * Called when Samsung Pay able to create in-app cryptogram successfully.
       * Partner app will send this cryptogram to Partner server/Payment Gateway and complete in-app payment.
       */

//      Log.d(TAG, "Transaction : paymentCredential " + paymentCredential);
      SamsungpayPlugin.this.result.success(paymentCredential);
//      mPaymentResultDialog.onSuccessDialog(response, paymentCredential, extraPaymentData);
      displayToastMessageIfRequired("Transaction : onSuccess");
    }

    // This callback is received when the online payment transaction has failed.
    @Override
    public void onFailure(int errorCode, Bundle errorData) {
      try {
        String errorName = ErrorCode.getInstance().getErrorCodeName(errorCode);
        int extraReason = 0;
        String extraReasonMsg = null;
        if (errorData != null) {
          extraReason = errorData.getInt(SamsungPay.EXTRA_ERROR_REASON);
          extraReasonMsg = errorData.getString(SamsungPay.EXTRA_ERROR_REASON_MESSAGE);
        }
        Log.d(TAG, "Transaction : onFailure " + errorCode + " / " + errorName + " / " + extraReason);
        displayToastMessageIfRequired("Transaction : onFailure - " + errorCode + " / " + errorName
                + " / " + extraReasonMsg);
      } catch (NullPointerException e) {
        e.printStackTrace();
      }
    }
  };
  private PartnerInfo getPartnerInfo(){
    Bundle bundle = new Bundle();
    bundle.putString(SamsungPay.PARTNER_SERVICE_TYPE, SamsungPay.ServiceType.INAPP_PAYMENT.toString());
    PartnerInfo partnerInfo = new PartnerInfo(SPAY_SERVICE_ID, bundle);  
    if(testmode)
    {
      partnerInfo.getData().putBoolean(PaymentManager.EXTRA_KEY_TEST_MODE, testmode);
    }
   

    return partnerInfo;
  }
  private void doActivateSamsungPay() {

    SamsungPay samsungPay = new SamsungPay(binding.getApplicationContext(), getPartnerInfo());
    samsungPay.activateSamsungPay();
  }
  private void samsungpay(@NonNull Result result) {
    final SamsungPay samsungPay = new SamsungPay(binding.getApplicationContext(), getPartnerInfo());
    samsungPay.getSamsungPayStatus(new StatusListener() {
      @Override
      public void onSuccess(int status, Bundle bundle) {
        switch (status) {
        case SamsungPay.SPAY_NOT_SUPPORTED:
          result.error("SPAY_NOT_SUPPORTED", "SPAY_NOT_SUPPORTED", null);
          break;
        case SamsungPay.SPAY_NOT_READY: // Activate Samsung Pay or update Samsung Pay, if needed
          int extra_reason = bundle.getInt(SamsungPay.EXTRA_ERROR_REASON);
          switch (extra_reason) {
          case SamsungPay.ERROR_SPAY_APP_NEED_TO_UPDATE:
            result.error("ERROR_SPAY_APP_NEED_TO_UPDATE", "ERROR_SPAY_APP_NEED_TO_UPDATE", null);
            break;
          case SamsungPay.ERROR_SPAY_SETUP_NOT_COMPLETED:
            samsungPay.activateSamsungPay();
            break;
          default:
            result.error("NOT_READY", "extra reason: " + extra_reason, null);
          }
          break;
        case SamsungPay.SPAY_READY:
          result.success("SPAY_READY");
 
          PaymentManager mPaymentManager = new PaymentManager(binding.getApplicationContext(), getPartnerInfo());

          break;
        default:// Not expected result

          result.error("UNKNOWN", "UNKNOWN", null);
          break;
        }
      }

      @Override
      public void onFail(int errorCode, Bundle bundle) {

        Log.d("SAM", "Failed to initialize Samsung Pay service." + errorCode);
        result.error("UNKNOWN", "UNKNOWN", null);
      }
    });
  }

}
